@@ -2,7 +2,7 @@ package RRDGraphTest003::Controller::Root;
 
 use strict;
 use warnings;
-use parent 'Catalyst::Controller';
+use base 'Catalyst::Controller';
 
 #
 # Sets the actions in this controller to be registered with no prefix
